@@ -1,7 +1,9 @@
-/* A Bison parser, made by GNU Bison 1.875.  */
+/* A Bison parser, made by GNU Bison 2.3.  */
 
-/* Skeleton parser for Yacc-like parsing with Bison,
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002 Free Software Foundation, Inc.
+/* Skeleton interface for Bison's Yacc-like parsers in C
+
+   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
+   Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -15,13 +17,21 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.  */
 
-/* As a special exception, when this file is copied by Bison into a
-   Bison output file, you may use that output file without restriction.
-   This special exception was added by the Free Software Foundation
-   in version 1.24 of Bison.  */
+/* As a special exception, you may create a larger work that contains
+   part or all of the Bison parser skeleton and distribute that work
+   under terms of your choice, so long as that work isn't itself a
+   parser generator using the skeleton or a modified version thereof
+   as a parser skeleton.  Alternatively, if you modify or redistribute
+   the parser skeleton itself, you may (at your option) remove this
+   special exception, which will cause the skeleton and the resulting
+   Bison output files to be licensed under the GNU General Public
+   License without this special exception.
+
+   This special exception was added by the Free Software Foundation in
+   version 2.2 of Bison.  */
 
 /* Tokens.  */
 #ifndef YYTOKENTYPE
@@ -120,35 +130,42 @@
      GREATERTHAN = 346,
      MODULO = 347,
      DELETE_KW = 348,
-     TYPES = 349,
-     PARMS = 350,
-     NONID = 351,
-     DSTAR = 352,
-     DCNOT = 353,
-     TEMPLATE = 354,
-     OPERATOR = 355,
-     COPERATOR = 356,
-     PARSETYPE = 357,
-     PARSEPARM = 358,
-     PARSEPARMS = 359,
-     CAST = 360,
-     LOR = 361,
-     LAND = 362,
-     OR = 363,
-     XOR = 364,
-     AND = 365,
-     RSHIFT = 366,
-     LSHIFT = 367,
-     MINUS = 368,
-     PLUS = 369,
-     SLASH = 370,
-     STAR = 371,
-     LNOT = 372,
-     NOT = 373,
-     UMINUS = 374,
-     DCOLON = 375
+     LESSTHANOREQUALTO = 349,
+     GREATERTHANOREQUALTO = 350,
+     EQUALTO = 351,
+     NOTEQUALTO = 352,
+     QUESTIONMARK = 353,
+     TYPES = 354,
+     PARMS = 355,
+     NONID = 356,
+     DSTAR = 357,
+     DCNOT = 358,
+     TEMPLATE = 359,
+     OPERATOR = 360,
+     COPERATOR = 361,
+     PARSETYPE = 362,
+     PARSEPARM = 363,
+     PARSEPARMS = 364,
+     CAST = 365,
+     LOR = 366,
+     LAND = 367,
+     OR = 368,
+     XOR = 369,
+     AND = 370,
+     RSHIFT = 371,
+     LSHIFT = 372,
+     MINUS = 373,
+     PLUS = 374,
+     MODULUS = 375,
+     SLASH = 376,
+     STAR = 377,
+     LNOT = 378,
+     NOT = 379,
+     UMINUS = 380,
+     DCOLON = 381
    };
 #endif
+/* Tokens.  */
 #define ID 258
 #define HBLOCK 259
 #define POUND 260
@@ -240,40 +257,47 @@
 #define GREATERTHAN 346
 #define MODULO 347
 #define DELETE_KW 348
-#define TYPES 349
-#define PARMS 350
-#define NONID 351
-#define DSTAR 352
-#define DCNOT 353
-#define TEMPLATE 354
-#define OPERATOR 355
-#define COPERATOR 356
-#define PARSETYPE 357
-#define PARSEPARM 358
-#define PARSEPARMS 359
-#define CAST 360
-#define LOR 361
-#define LAND 362
-#define OR 363
-#define XOR 364
-#define AND 365
-#define RSHIFT 366
-#define LSHIFT 367
-#define MINUS 368
-#define PLUS 369
-#define SLASH 370
-#define STAR 371
-#define LNOT 372
-#define NOT 373
-#define UMINUS 374
-#define DCOLON 375
+#define LESSTHANOREQUALTO 349
+#define GREATERTHANOREQUALTO 350
+#define EQUALTO 351
+#define NOTEQUALTO 352
+#define QUESTIONMARK 353
+#define TYPES 354
+#define PARMS 355
+#define NONID 356
+#define DSTAR 357
+#define DCNOT 358
+#define TEMPLATE 359
+#define OPERATOR 360
+#define COPERATOR 361
+#define PARSETYPE 362
+#define PARSEPARM 363
+#define PARSEPARMS 364
+#define CAST 365
+#define LOR 366
+#define LAND 367
+#define OR 368
+#define XOR 369
+#define AND 370
+#define RSHIFT 371
+#define LSHIFT 372
+#define MINUS 373
+#define PLUS 374
+#define MODULUS 375
+#define SLASH 376
+#define STAR 377
+#define LNOT 378
+#define NOT 379
+#define UMINUS 380
+#define DCOLON 381
 
 
 
 
-#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
-#line 1330 "parser.y"
-typedef union YYSTYPE {
+#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
+typedef union YYSTYPE
+#line 1349 "parser.y"
+{
   char  *id;
   List  *bases;
   struct Define {
@@ -287,7 +311,7 @@ typedef union YYSTYPE {
   } dtype;
   struct {
     char *type;
-    char *filename;
+    String *filename;
     int   line;
   } loc;
   struct {
@@ -314,9 +338,10 @@ typedef union YYSTYPE {
   ParmList     *pl;
   int           ivalue;
   Node         *node;
-} YYSTYPE;
-/* Line 1249 of yacc.c.  */
-#line 319 "y.tab.h"
+}
+/* Line 1489 of yacc.c.  */
+#line 344 "y.tab.h"
+	YYSTYPE;
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 # define YYSTYPE_IS_TRIVIAL 1
@@ -324,5 +349,3 @@ typedef union YYSTYPE {
 
 extern YYSTYPE yylval;
 
-
-
