@@ -10,7 +10,7 @@
  * See the file LICENSE for information on usage and redistribution.	
  * ----------------------------------------------------------------------------- */
 
-char cvsroot_file_c[] = "$Header: /cvsroot/swig/SWIG/Source/DOH/file.c,v 1.6 2006/01/17 00:52:34 marcelomatus Exp $";
+char cvsroot_file_c[] = "$Id: file.c 9607 2006-12-05 22:11:40Z beazley $";
 
 #include "dohint.h"
 
@@ -20,17 +20,16 @@ char cvsroot_file_c[] = "$Header: /cvsroot/swig/SWIG/Source/DOH/file.c,v 1.6 200
 #include <errno.h>
 
 typedef struct {
-  FILE     *filep;       
-  int       fd;
-  int       closeondel;
+  FILE *filep;
+  int fd;
+  int closeondel;
 } DohFile;
 
 /* -----------------------------------------------------------------------------
  * DelFile()
  * ----------------------------------------------------------------------------- */
 
-static void
-DelFile(DOH *fo) {
+static void DelFile(DOH *fo) {
   DohFile *f = (DohFile *) ObjData(fo);
   if (f->closeondel) {
     if (f->filep) {
@@ -49,15 +48,14 @@ DelFile(DOH *fo) {
  * File_read()
  * ----------------------------------------------------------------------------- */
 
-static int
-File_read(DOH *fo, void *buffer, int len) {
+static int File_read(DOH *fo, void *buffer, int len) {
   DohFile *f = (DohFile *) ObjData(fo);
-  
+
   if (f->filep) {
-    return fread(buffer,1,len,f->filep);
+    return fread(buffer, 1, len, f->filep);
   } else if (f->fd) {
 #ifdef DOH_INTFILE
-    return read(f->fd,buffer,len);
+    return read(f->fd, buffer, len);
 #endif
   }
   return -1;
@@ -67,16 +65,15 @@ File_read(DOH *fo, void *buffer, int len) {
  * File_write()
  * ----------------------------------------------------------------------------- */
 
-static int
-File_write(DOH *fo, void *buffer, int len) {
+static int File_write(DOH *fo, void *buffer, int len) {
   DohFile *f = (DohFile *) ObjData(fo);
   if (f->filep) {
     int ret = (int) fwrite(buffer, 1, len, f->filep);
     int err = (ret != len) ? ferror(f->filep) : 0;
-    return err ? -1: ret;
+    return err ? -1 : ret;
   } else if (f->fd) {
 #ifdef DOH_INTFILE
-    return write(f->fd,buffer,len);
+    return write(f->fd, buffer, len);
 #endif
   }
   return -1;
@@ -86,11 +83,10 @@ File_write(DOH *fo, void *buffer, int len) {
  * File_seek()
  * ----------------------------------------------------------------------------- */
 
-static int
-File_seek(DOH *fo, long offset, int whence) {
+static int File_seek(DOH *fo, long offset, int whence) {
   DohFile *f = (DohFile *) ObjData(fo);
   if (f->filep) {
-    return fseek(f->filep,offset,whence);
+    return fseek(f->filep, offset, whence);
   } else if (f->fd) {
 #ifdef DOH_INTFILE
     return lseek(f->fd, offset, whence);
@@ -103,8 +99,7 @@ File_seek(DOH *fo, long offset, int whence) {
  * File_tell()
  * ----------------------------------------------------------------------------- */
 
-static long
-File_tell(DOH *fo) {
+static long File_tell(DOH *fo) {
   DohFile *f = (DohFile *) ObjData(fo);
   if (f->filep) {
     return ftell(f->filep);
@@ -120,16 +115,15 @@ File_tell(DOH *fo) {
  * File_putc()
  * ----------------------------------------------------------------------------- */
 
-static int 
-File_putc(DOH *fo, int ch) {
+static int File_putc(DOH *fo, int ch) {
   DohFile *f = (DohFile *) ObjData(fo);
   if (f->filep) {
-    return fputc(ch,f->filep);
+    return fputc(ch, f->filep);
   } else if (f->fd) {
 #ifdef DOH_INTFILE
     char c;
     c = (char) ch;
-    return write(f->fd,&c,1);
+    return write(f->fd, &c, 1);
 #endif
   }
   return -1;
@@ -139,15 +133,15 @@ File_putc(DOH *fo, int ch) {
  * File_getc()
  * ----------------------------------------------------------------------------- */
 
-static int 
-File_getc(DOH *fo) {
+static int File_getc(DOH *fo) {
   DohFile *f = (DohFile *) ObjData(fo);
   if (f->filep) {
     return fgetc(f->filep);
   } else if (f->fd) {
 #ifdef DOH_INTFILE
     char c;
-    if (read(f->fd,&c,1) < 0) return EOF;
+    if (read(f->fd, &c, 1) < 0)
+      return EOF;
     return c;
 #endif
   }
@@ -160,8 +154,7 @@ File_getc(DOH *fo) {
  * Put a character back onto the input
  * ----------------------------------------------------------------------------- */
 
-static int 
-File_ungetc(DOH *fo, int ch) {
+static int File_ungetc(DOH *fo, int ch) {
   DohFile *f = (DohFile *) ObjData(fo);
   if (f->filep) {
     return ungetc(ch, f->filep);
@@ -179,8 +172,7 @@ File_ungetc(DOH *fo, int ch) {
  * Close the file
  * ----------------------------------------------------------------------------- */
 
-static int
-File_close(DOH *fo) {
+static int File_close(DOH *fo) {
   int ret = 0;
   DohFile *f = (DohFile *) ObjData(fo);
   if (f->filep) {
@@ -196,40 +188,40 @@ File_close(DOH *fo) {
 }
 
 static DohFileMethods FileFileMethods = {
-  File_read, 
+  File_read,
   File_write,
   File_putc,
   File_getc,
   File_ungetc,
   File_seek,
   File_tell,
-  File_close,           /* close */
+  File_close,			/* close */
 };
 
 static DohObjInfo DohFileType = {
-    "DohFile",          /* objname      */
-    DelFile,         /* doh_del      */
-    0,               /* doh_copy     */
-    0,               /* doh_clear    */
-    0,               /* doh_str      */
-    0,               /* doh_data     */
-    0,               /* doh_dump     */
-    0,               /* doh_len      */
-    0,               /* doh_hash     */
-    0,               /* doh_cmp      */
-    0,               /* doh_equal    */
-    0,               /* doh_first    */
-    0,               /* doh_next     */
-    0,               /* doh_setfile  */
-    0,               /* doh_getfile  */
-    0,               /* doh_setline  */
-    0,               /* doh_getline  */
-    0,               /* doh_mapping  */
-    0,               /* doh_sequence */
-    &FileFileMethods,/* doh_file     */
-    0,               /* doh_string   */
-    0,               /* doh_callable */
-    0,               /* doh_position */
+  "DohFile",			/* objname      */
+  DelFile,			/* doh_del      */
+  0,				/* doh_copy     */
+  0,				/* doh_clear    */
+  0,				/* doh_str      */
+  0,				/* doh_data     */
+  0,				/* doh_dump     */
+  0,				/* doh_len      */
+  0,				/* doh_hash     */
+  0,				/* doh_cmp      */
+  0,				/* doh_equal    */
+  0,				/* doh_first    */
+  0,				/* doh_next     */
+  0,				/* doh_setfile  */
+  0,				/* doh_getfile  */
+  0,				/* doh_setline  */
+  0,				/* doh_getline  */
+  0,				/* doh_mapping  */
+  0,				/* doh_sequence */
+  &FileFileMethods,		/* doh_file     */
+  0,				/* doh_string   */
+  0,				/* doh_callable */
+  0,				/* doh_position */
 };
 
 /* -----------------------------------------------------------------------------
@@ -238,16 +230,15 @@ static DohObjInfo DohFileType = {
  * Create a new file from a given filename and mode.
  * ----------------------------------------------------------------------------- */
 
-DOH *
-DohNewFile(DOH *fn, const char *mode)
-{
+DOH *DohNewFile(DOH *fn, const char *mode) {
   DohFile *f;
   FILE *file;
   char *filename;
 
   filename = Char(fn);
-  file = fopen(filename,mode);
-  if (!file) return 0;
+  file = fopen(filename, mode);
+  if (!file)
+    return 0;
 
   f = (DohFile *) DohMalloc(sizeof(DohFile));
   if (!f) {
@@ -257,7 +248,7 @@ DohNewFile(DOH *fn, const char *mode)
   f->filep = file;
   f->fd = 0;
   f->closeondel = 1;
-  return DohObjMalloc(&DohFileType,f);
+  return DohObjMalloc(&DohFileType, f);
 }
 
 /* -----------------------------------------------------------------------------
@@ -266,16 +257,15 @@ DohNewFile(DOH *fn, const char *mode)
  * Create a file object from an already open FILE *.
  * ----------------------------------------------------------------------------- */
 
-DOH *
-DohNewFileFromFile(FILE *file) 
-{
+DOH *DohNewFileFromFile(FILE *file) {
   DohFile *f;
   f = (DohFile *) DohMalloc(sizeof(DohFile));
-  if (!f) return 0;
+  if (!f)
+    return 0;
   f->filep = file;
   f->fd = 0;
   f->closeondel = 0;
-  return DohObjMalloc(&DohFileType,f);
+  return DohObjMalloc(&DohFileType, f);
 }
 
 /* -----------------------------------------------------------------------------
@@ -284,16 +274,15 @@ DohNewFileFromFile(FILE *file)
  * Create a file object from an already open FILE *.
  * ----------------------------------------------------------------------------- */
 
-DOH *
-DohNewFileFromFd(int fd)
-{
+DOH *DohNewFileFromFd(int fd) {
   DohFile *f;
   f = (DohFile *) DohMalloc(sizeof(DohFile));
-  if (!f) return 0;
+  if (!f)
+    return 0;
   f->filep = 0;
   f->fd = fd;
   f->closeondel = 0;
-  return DohObjMalloc(&DohFileType,f);
+  return DohObjMalloc(&DohFileType, f);
 }
 
 /* -----------------------------------------------------------------------------
@@ -302,9 +291,6 @@ DohNewFileFromFd(int fd)
  * Display cause of one of the NewFile functions failing.
  * ----------------------------------------------------------------------------- */
 
-void
-DohFileErrorDisplay(DOHString *filename)
-{
+void DohFileErrorDisplay(DOHString * filename) {
   Printf(stderr, "Unable to open file %s: %s\n", filename, strerror(errno));
 }
-
