@@ -1,22 +1,25 @@
-/* SWIG warning message numbers
+/* ----------------------------------------------------------------------------- 
+ * See the LICENSE file for information on copyright, usage and redistribution
+ * of SWIG, and the README file for authors - http://www.swig.org/release.html.
+ *
+ * swigwarn.h
+ *
+ * SWIG warning message numbers
+ * This file serves as the main registry of warning message numbers.  Some of these
+ * numbers are used internally in the C/C++ source code of SWIG.   However, some
+ * of the numbers are used in SWIG configuration files (swig.swg and others).
+ *
+ * The numbers are roughly organized into a few different classes by functionality.
+ *
+ * Even though symbolic constants are used in the SWIG source, this is
+ * not always the case in SWIG interface files.  Do not change the
+ * numbers in this file.
+ * ----------------------------------------------------------------------------- */
 
-   This file serves as the main registry of warning message numbers.  Some of these
-   numbers are used internally in the C/C++ source code of SWIG.   However, some
-   of the numbers are used in SWIG configuration files (swig.swg and others).
+/* $Id: swigwarn.h 9906 2007-08-17 20:42:19Z wsfulton $ */
 
-   The numbers are roughly organized into a few different classes by functionality.
-
-   Even though symbolic constants are used in the SWIG source, this is
-   not always the case in SWIG interface files.  Do not change the
-   numbers in this file.
-
- */
-
-
-
-
-#ifndef _SWIGWARN_H
-#define _SWIGWARN_H 1
+#ifndef SWIGWARN_H_
+#define SWIGWARN_H_
 
 #define WARN_NONE                     0
 
@@ -79,54 +82,55 @@
 #define WARN_PARSE_EXPLICIT_TEMPLATE  320
 #define WARN_PARSE_BUILTIN_NAME       321
 #define WARN_PARSE_REDUNDANT          322
+#define WARN_PARSE_REC_INHERITANCE    323
 
-#define WARN_IGNORE_OPERATOR_NEW        350   /* new */
-#define WARN_IGNORE_OPERATOR_DELETE     351   /* delete */
-#define WARN_IGNORE_OPERATOR_PLUS       352   /* + */
-#define WARN_IGNORE_OPERATOR_MINUS      353   /* - */
-#define WARN_IGNORE_OPERATOR_MUL        354   /* * */
-#define WARN_IGNORE_OPERATOR_DIV        355   /* / */
-#define WARN_IGNORE_OPERATOR_MOD        356   /* % */
-#define WARN_IGNORE_OPERATOR_XOR        357   /* ^ */
-#define WARN_IGNORE_OPERATOR_AND        358   /* & */
-#define WARN_IGNORE_OPERATOR_OR         359   /* | */
-#define WARN_IGNORE_OPERATOR_NOT        360   /* ~ */
-#define WARN_IGNORE_OPERATOR_LNOT       361   /* ! */
-#define WARN_IGNORE_OPERATOR_EQ         362   /* = */
-#define WARN_IGNORE_OPERATOR_LT         363   /* < */
-#define WARN_IGNORE_OPERATOR_GT         364   /* > */
-#define WARN_IGNORE_OPERATOR_PLUSEQ     365   /* += */
-#define WARN_IGNORE_OPERATOR_MINUSEQ    366   /* -= */
-#define WARN_IGNORE_OPERATOR_MULEQ      367   /* *= */
-#define WARN_IGNORE_OPERATOR_DIVEQ      368   /* /= */
-#define WARN_IGNORE_OPERATOR_MODEQ      369   /* %= */
-#define WARN_IGNORE_OPERATOR_XOREQ      370   /* ^= */
-#define WARN_IGNORE_OPERATOR_ANDEQ      371   /* &= */
-#define WARN_IGNORE_OPERATOR_OREQ       372   /* |= */
-#define WARN_IGNORE_OPERATOR_LSHIFT     373   /* << */
-#define WARN_IGNORE_OPERATOR_RSHIFT     374   /* >> */
-#define WARN_IGNORE_OPERATOR_LSHIFTEQ   375   /* <<= */
-#define WARN_IGNORE_OPERATOR_RSHIFTEQ   376   /* >>= */
-#define WARN_IGNORE_OPERATOR_EQUALTO    377   /* == */
-#define WARN_IGNORE_OPERATOR_NOTEQUAL   378   /* != */
-#define WARN_IGNORE_OPERATOR_LTEQUAL    379   /* <= */
-#define WARN_IGNORE_OPERATOR_GTEQUAL    380   /* >= */
-#define WARN_IGNORE_OPERATOR_LAND       381   /* && */
-#define WARN_IGNORE_OPERATOR_LOR        382   /* || */
-#define WARN_IGNORE_OPERATOR_PLUSPLUS   383   /* ++ */
-#define WARN_IGNORE_OPERATOR_MINUSMINUS 384   /* -- */
-#define WARN_IGNORE_OPERATOR_COMMA      385   /* , */
-#define WARN_IGNORE_OPERATOR_ARROWSTAR  386   /* ->* */
-#define WARN_IGNORE_OPERATOR_ARROW      387   /* -> */
-#define WARN_IGNORE_OPERATOR_CALL       388   /* () */
-#define WARN_IGNORE_OPERATOR_INDEX      389   /* [] */
-#define WARN_IGNORE_OPERATOR_UPLUS      390   /* + */
-#define WARN_IGNORE_OPERATOR_UMINUS     391   /* - */
-#define WARN_IGNORE_OPERATOR_UMUL       392   /* * */
-#define WARN_IGNORE_OPERATOR_UAND       393   /* & */
-#define WARN_IGNORE_OPERATOR_NEWARR     394   /* new [] */
-#define WARN_IGNORE_OPERATOR_DELARR     395   /* delete [] */
-#define WARN_IGNORE_OPERATOR_REF        396   /* operator *() */
+#define WARN_IGNORE_OPERATOR_NEW        350	/* new */
+#define WARN_IGNORE_OPERATOR_DELETE     351	/* delete */
+#define WARN_IGNORE_OPERATOR_PLUS       352	/* + */
+#define WARN_IGNORE_OPERATOR_MINUS      353	/* - */
+#define WARN_IGNORE_OPERATOR_MUL        354	/* * */
+#define WARN_IGNORE_OPERATOR_DIV        355	/* / */
+#define WARN_IGNORE_OPERATOR_MOD        356	/* % */
+#define WARN_IGNORE_OPERATOR_XOR        357	/* ^ */
+#define WARN_IGNORE_OPERATOR_AND        358	/* & */
+#define WARN_IGNORE_OPERATOR_OR         359	/* | */
+#define WARN_IGNORE_OPERATOR_NOT        360	/* ~ */
+#define WARN_IGNORE_OPERATOR_LNOT       361	/* ! */
+#define WARN_IGNORE_OPERATOR_EQ         362	/* = */
+#define WARN_IGNORE_OPERATOR_LT         363	/* < */
+#define WARN_IGNORE_OPERATOR_GT         364	/* > */
+#define WARN_IGNORE_OPERATOR_PLUSEQ     365	/* += */
+#define WARN_IGNORE_OPERATOR_MINUSEQ    366	/* -= */
+#define WARN_IGNORE_OPERATOR_MULEQ      367	/* *= */
+#define WARN_IGNORE_OPERATOR_DIVEQ      368	/* /= */
+#define WARN_IGNORE_OPERATOR_MODEQ      369	/* %= */
+#define WARN_IGNORE_OPERATOR_XOREQ      370	/* ^= */
+#define WARN_IGNORE_OPERATOR_ANDEQ      371	/* &= */
+#define WARN_IGNORE_OPERATOR_OREQ       372	/* |= */
+#define WARN_IGNORE_OPERATOR_LSHIFT     373	/* << */
+#define WARN_IGNORE_OPERATOR_RSHIFT     374	/* >> */
+#define WARN_IGNORE_OPERATOR_LSHIFTEQ   375	/* <<= */
+#define WARN_IGNORE_OPERATOR_RSHIFTEQ   376	/* >>= */
+#define WARN_IGNORE_OPERATOR_EQUALTO    377	/* == */
+#define WARN_IGNORE_OPERATOR_NOTEQUAL   378	/* != */
+#define WARN_IGNORE_OPERATOR_LTEQUAL    379	/* <= */
+#define WARN_IGNORE_OPERATOR_GTEQUAL    380	/* >= */
+#define WARN_IGNORE_OPERATOR_LAND       381	/* && */
+#define WARN_IGNORE_OPERATOR_LOR        382	/* || */
+#define WARN_IGNORE_OPERATOR_PLUSPLUS   383	/* ++ */
+#define WARN_IGNORE_OPERATOR_MINUSMINUS 384	/* -- */
+#define WARN_IGNORE_OPERATOR_COMMA      385	/* , */
+#define WARN_IGNORE_OPERATOR_ARROWSTAR  386	/* ->* */
+#define WARN_IGNORE_OPERATOR_ARROW      387	/* -> */
+#define WARN_IGNORE_OPERATOR_CALL       388	/* () */
+#define WARN_IGNORE_OPERATOR_INDEX      389	/* [] */
+#define WARN_IGNORE_OPERATOR_UPLUS      390	/* + */
+#define WARN_IGNORE_OPERATOR_UMINUS     391	/* - */
+#define WARN_IGNORE_OPERATOR_UMUL       392	/* * */
+#define WARN_IGNORE_OPERATOR_UAND       393	/* & */
+#define WARN_IGNORE_OPERATOR_NEWARR     394	/* new [] */
+#define WARN_IGNORE_OPERATOR_DELARR     395	/* delete [] */
+#define WARN_IGNORE_OPERATOR_REF        396	/* operator *() */
 
 /* 394-399 are reserved */
 
@@ -153,10 +157,10 @@
 #define WARN_TYPEMAP_TYPECHECK        467
 #define WARN_TYPEMAP_THROW            468
 #define WARN_TYPEMAP_DIRECTORIN_UNDEF  469
-#define WARN_TYPEMAP_THREAD_UNSAFE     470 /* mostly used in directorout typemaps */
+#define WARN_TYPEMAP_THREAD_UNSAFE     470	/* mostly used in directorout typemaps */
 #define WARN_TYPEMAP_DIRECTOROUT_UNDEF 471
 #define WARN_TYPEMAP_TYPECHECK_UNDEF   472
-#define WARN_TYPEMAP_DIRECTOROUT_PTR   473 
+#define WARN_TYPEMAP_DIRECTOROUT_PTR   473
 
 /* -- Fragments -- */
 #define WARN_FRAGMENT_NOT_FOUND       490
@@ -167,7 +171,7 @@
 #define WARN_LANG_OVERLOAD_CONSTRUCT  502
 #define WARN_LANG_IDENTIFIER          503
 #define WARN_LANG_RETURN_TYPE         504
-#define WARN_LANG_VARARGS             505 
+#define WARN_LANG_VARARGS             505
 #define WARN_LANG_VARARGS_KEYWORD     506
 #define WARN_LANG_NATIVE_UNIMPL       507
 #define WARN_LANG_DEREF_SHADOW        508
@@ -181,6 +185,7 @@
 #define WARN_LANG_OVERLOAD_IGNORED    516
 #define WARN_LANG_DIRECTOR_ABSTRACT   517
 #define WARN_LANG_PORTABILITY_FILENAME 518
+#define WARN_LANG_TEMPLATE_METHOD_IGNORE 519
 
 /* -- Reserved (600-799) -- */
 
@@ -222,6 +227,7 @@
 #define WARN_CSHARP_TYPEMAP_CSCONSTRUCT_UNDEF 843
 #define WARN_CSHARP_EXCODE                    844
 #define WARN_CSHARP_CANTHROW                  845
+#define WARN_CSHARP_NO_DIRECTORCONNECT_ATTR   846
 
 /* please leave 830-849 free for C# */
 
@@ -239,16 +245,13 @@
 
 /* please leave 850-869 free for Modula 3 */
 
+#define WARN_PHP4_MULTIPLE_INHERITANCE         870
+#define WARN_PHP4_UNKNOWN_PRAGMA               871
 
 /* please leave 870-889 free for Php */
-#define WARN_PHP4_MULTIPLE_INHERITANCE        870
-
 
 
 /* Feel free to claim any number in this space that's not currently being used. Just make sure you
    add an entry here */
 
 #endif
-
-
-
