@@ -9,7 +9,7 @@
  * building a dispatch function.
  * ----------------------------------------------------------------------------- */
 
-char cvsroot_overload_cxx[] = "$Header: /cvsroot/swig/SWIG/Source/Modules/overload.cxx,v 1.24 2006/11/01 23:54:52 wsfulton Exp $";
+char cvsroot_overload_cxx[] = "$Id: overload.cxx 10003 2007-10-17 21:42:11Z wsfulton $";
 
 #include "swigmod.h"
 
@@ -142,7 +142,7 @@ static List *Swig_overload_rank(Node *n, bool script_lang_wrapping) {
 	      differ = t1v - t2v;
 	    } else if (!t1 && t2)
 	      differ = 1;
-	    else if (t2 && !t1)
+	    else if (t1 && !t2)
 	      differ = -1;
 	    else if (!t1 && !t2)
 	      differ = -1;
@@ -224,13 +224,13 @@ static List *Swig_overload_rank(Node *n, bool script_lang_wrapping) {
 		    if (script_lang_wrapping) {
 		      Swig_warning(WARN_LANG_OVERLOAD_CONST, Getfile(nodes[j].n), Getline(nodes[j].n),
 				   "Overloaded %s(%s) const ignored. Non-const method at %s:%d used.\n",
-				   Getattr(nodes[j].n, "name"), ParmList_protostr(nodes[j].parms), Getfile(nodes[i].n), Getline(nodes[i].n));
+				   Getattr(nodes[j].n, "name"), ParmList_errorstr(nodes[j].parms), Getfile(nodes[i].n), Getline(nodes[i].n));
 		    } else {
 		      if (!Getattr(nodes[j].n, "overload:ignore"))
 			Swig_warning(WARN_LANG_OVERLOAD_IGNORED, Getfile(nodes[j].n), Getline(nodes[j].n),
 				     "Overloaded method %s(%s) ignored. Method %s(%s) const at %s:%d used.\n",
-				     Getattr(nodes[j].n, "name"), ParmList_protostr(nodes[j].parms),
-				     Getattr(nodes[i].n, "name"), ParmList_protostr(nodes[i].parms), Getfile(nodes[i].n), Getline(nodes[i].n));
+				     Getattr(nodes[j].n, "name"), ParmList_errorstr(nodes[j].parms),
+				     Getattr(nodes[i].n, "name"), ParmList_errorstr(nodes[i].parms), Getfile(nodes[i].n), Getline(nodes[i].n));
 		    }
 		  }
 		  nodes[j].error = 1;
@@ -240,13 +240,13 @@ static List *Swig_overload_rank(Node *n, bool script_lang_wrapping) {
 		    if (script_lang_wrapping) {
 		      Swig_warning(WARN_LANG_OVERLOAD_CONST, Getfile(nodes[j].n), Getline(nodes[j].n),
 				   "Overloaded %s(%s) const ignored. Non-const method at %s:%d used.\n",
-				   Getattr(nodes[j].n, "name"), ParmList_protostr(nodes[j].parms), Getfile(nodes[i].n), Getline(nodes[i].n));
+				   Getattr(nodes[j].n, "name"), ParmList_errorstr(nodes[j].parms), Getfile(nodes[i].n), Getline(nodes[i].n));
 		    } else {
 		      if (!Getattr(nodes[j].n, "overload:ignore"))
 			Swig_warning(WARN_LANG_OVERLOAD_IGNORED, Getfile(nodes[j].n), Getline(nodes[j].n),
 				     "Overloaded method %s(%s) const ignored. Method %s(%s) at %s:%d used.\n",
-				     Getattr(nodes[j].n, "name"), ParmList_protostr(nodes[j].parms),
-				     Getattr(nodes[i].n, "name"), ParmList_protostr(nodes[i].parms), Getfile(nodes[i].n), Getline(nodes[i].n));
+				     Getattr(nodes[j].n, "name"), ParmList_errorstr(nodes[j].parms),
+				     Getattr(nodes[i].n, "name"), ParmList_errorstr(nodes[i].parms), Getfile(nodes[i].n), Getline(nodes[i].n));
 		    }
 		  }
 		  nodes[j].error = 1;
@@ -261,17 +261,17 @@ static List *Swig_overload_rank(Node *n, bool script_lang_wrapping) {
 	      if (script_lang_wrapping) {
 		Swig_warning(WARN_LANG_OVERLOAD_SHADOW, Getfile(nodes[j].n), Getline(nodes[j].n),
 			     "Overloaded %s(%s)%s is shadowed by %s(%s)%s at %s:%d.\n",
-			     Getattr(nodes[j].n, "name"), ParmList_protostr(nodes[j].parms),
+			     Getattr(nodes[j].n, "name"), ParmList_errorstr(nodes[j].parms),
 			     SwigType_isconst(Getattr(nodes[j].n, "decl")) ? " const" : "",
-			     Getattr(nodes[i].n, "name"), ParmList_protostr(nodes[i].parms),
+			     Getattr(nodes[i].n, "name"), ParmList_errorstr(nodes[i].parms),
 			     SwigType_isconst(Getattr(nodes[i].n, "decl")) ? " const" : "", Getfile(nodes[i].n), Getline(nodes[i].n));
 	      } else {
 		if (!Getattr(nodes[j].n, "overload:ignore"))
 		  Swig_warning(WARN_LANG_OVERLOAD_IGNORED, Getfile(nodes[j].n), Getline(nodes[j].n),
 			       "Overloaded method %s(%s)%s ignored. Method %s(%s)%s at %s:%d used.\n",
-			       Getattr(nodes[j].n, "name"), ParmList_protostr(nodes[j].parms),
+			       Getattr(nodes[j].n, "name"), ParmList_errorstr(nodes[j].parms),
 			       SwigType_isconst(Getattr(nodes[j].n, "decl")) ? " const" : "",
-			       Getattr(nodes[i].n, "name"), ParmList_protostr(nodes[i].parms),
+			       Getattr(nodes[i].n, "name"), ParmList_errorstr(nodes[i].parms),
 			       SwigType_isconst(Getattr(nodes[i].n, "decl")) ? " const" : "", Getfile(nodes[i].n), Getline(nodes[i].n));
 	      }
 	      nodes[j].error = 1;
@@ -288,7 +288,7 @@ static List *Swig_overload_rank(Node *n, bool script_lang_wrapping) {
       if (nodes[i].error)
 	Setattr(nodes[i].n, "overload:ignore", "1");
       Append(result, nodes[i].n);
-      //      Printf(stdout,"[ %d ] %s\n", i, ParmList_protostr(nodes[i].parms));
+      //      Printf(stdout,"[ %d ] %s\n", i, ParmList_errorstr(nodes[i].parms));
       //      Swig_print_node(nodes[i].n);
     }
   }
@@ -489,9 +489,9 @@ String *Swig_overload_dispatch_cast(Node *n, const String_or_char *fmt, int *max
 	    Printv(f, "{\n", tm, "}\n", NIL);
 	    fn = i + 1;
 	    Printf(f, "if (!_v) goto check_%d;\n", fn);
-	    Printf(f, "_ranki += _v*_pi;\n", fn);
-	    Printf(f, "_rankm += _pi;\n", fn);
-	    Printf(f, "_pi *= SWIG_MAXCASTRANK;\n", fn);
+	    Printf(f, "_ranki += _v*_pi;\n");
+	    Printf(f, "_rankm += _pi;\n");
+	    Printf(f, "_pi *= SWIG_MAXCASTRANK;\n");
 	  }
 	}
 	if (!Getattr(pj, "tmap:in:SWIGTYPE") && Getattr(pj, "tmap:typecheck:SWIGTYPE")) {
@@ -513,10 +513,10 @@ String *Swig_overload_dispatch_cast(Node *n, const String_or_char *fmt, int *max
     for ( /* empty */ ; num_braces > 0; num_braces--)
       Printf(f, "}\n");
 
-    Printf(f, "if (!_index || (_ranki < _rank)) {\n", i + 1);
+    Printf(f, "if (!_index || (_ranki < _rank)) {\n");
     Printf(f, " _rank = _ranki; _index = %d;\n", i + 1);
-    Printf(f, " if (_rank == _rankm) goto dispatch;\n", i + 1);
-    Printf(f, "}\n", i + 1);
+    Printf(f, " if (_rank == _rankm) goto dispatch;\n");
+    Printf(f, "}\n");
     String *lfmt = ReplaceFormat(fmt, num_arguments);
     Printf(sw, "case %d:\n", i + 1);
     Printf(sw, Char(lfmt), Getattr(ni, "wrap:name"));
