@@ -7,7 +7,7 @@
  * Perl5 language module for SWIG.
  * ------------------------------------------------------------------------- */
 
-char cvsroot_perl5_cxx[] = "$Header: /cvsroot/swig/SWIG/Source/Modules/perl5.cxx,v 1.65 2006/11/15 23:45:47 wsfulton Exp $";
+char cvsroot_perl5_cxx[] = "$Id: perl5.cxx 10151 2007-11-19 21:30:57Z wsfulton $";
 
 #include "swigmod.h"
 #include "cparse.h"
@@ -135,12 +135,12 @@ public:
     for (i = 1; i < argc; i++) {
       if (argv[i]) {
 	if (strcmp(argv[i], "-package") == 0) {
-	  Printf(stderr,
-		 "*** -package is no longer supported\n*** use the directive '%module A::B::C' in your interface file instead\n*** see the Perl section in the manual for details.\n");
+	  Printv(stderr,
+		 "*** -package is no longer supported\n*** use the directive '%module A::B::C' in your interface file instead\n*** see the Perl section in the manual for details.\n", NIL);
 	  SWIG_exit(EXIT_FAILURE);
 	} else if (strcmp(argv[i], "-interface") == 0) {
-	  Printf(stderr,
-		 "*** -interface is no longer supported\n*** use the directive '%module A::B::C' in your interface file instead\n*** see the Perl section in the manual for details.\n");
+	  Printv(stderr,
+		 "*** -interface is no longer supported\n*** use the directive '%module A::B::C' in your interface file instead\n*** see the Perl section in the manual for details.\n", NIL);
 	  SWIG_exit(EXIT_FAILURE);
 	} else if (strcmp(argv[i], "-exportall") == 0) {
 	  export_all = 1;
@@ -304,6 +304,7 @@ public:
     /* Start creating magic code */
 
     Printv(magic,
+           "#ifdef __cplusplus\nextern \"C\" {\n#endif\n\n",
 	   "#ifdef PERL_OBJECT\n",
 	   "#define MAGIC_CLASS _wrap_", module, "_var::\n",
 	   "class _wrap_", module, "_var : public CPerlObj {\n",
@@ -324,6 +325,7 @@ public:
     /* Dump out variable wrappers */
 
     Printv(magic, "\n\n#ifdef PERL_OBJECT\n", "};\n", "#endif\n", NIL);
+    Printv(magic, "\n#ifdef __cplusplus\n}\n#endif\n", NIL);
 
     Printf(f_header, "%s\n", magic);
 
@@ -765,9 +767,11 @@ public:
     SwigType *t = Getattr(n, "type");
     Wrapper *getf, *setf;
     String *tm;
+    String *getname = Swig_name_get(iname);
+    String *setname = Swig_name_set(iname);
 
-    String *set_name = Swig_name_wrapper(Swig_name_set(iname));
-    String *val_name = Swig_name_wrapper(Swig_name_get(iname));
+    String *get_name = Swig_name_wrapper(getname);
+    String *set_name = Swig_name_wrapper(setname);
 
     if (!addSymbol(iname, n))
       return SWIG_ERROR;
@@ -801,7 +805,7 @@ public:
 
     /* Now write a function to evaluate the variable */
     int addfail = 0;
-    Printf(getf->def, "SWIGCLASS_STATIC int %s(pTHX_ SV *sv, MAGIC *SWIGUNUSEDPARM(mg)) {\n", val_name);
+    Printf(getf->def, "SWIGCLASS_STATIC int %s(pTHX_ SV *sv, MAGIC *SWIGUNUSEDPARM(mg)) {\n", get_name);
     Printv(getf->code, tab4, "MAGIC_PPERL\n", NIL);
 
     if ((tm = Swig_typemap_lookup_new("varout", n, name, 0))) {
@@ -817,6 +821,8 @@ public:
       addfail = emit_action_code(n, getf, tm);
     } else {
       Swig_warning(WARN_TYPEMAP_VAROUT_UNDEF, input_file, line_number, "Unable to read variable of type %s\n", SwigType_str(t, 0));
+      DelWrapper(setf);
+      DelWrapper(getf);
       return SWIG_NOWRAP;
     }
     Printf(getf->code, "    return 1;\n");
@@ -850,10 +856,10 @@ public:
     }
     /* Now add symbol to the PERL interpreter */
     if (GetFlag(n, "feature:immutable")) {
-      Printv(variable_tab, tab4, "{ \"", cmodule, "::", iname, "\", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS ", val_name, ",", tt, " },\n", NIL);
+      Printv(variable_tab, tab4, "{ \"", cmodule, "::", iname, "\", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS ", get_name, ",", tt, " },\n", NIL);
 
     } else {
-      Printv(variable_tab, tab4, "{ \"", cmodule, "::", iname, "\", MAGIC_CLASS ", set_name, ", MAGIC_CLASS ", val_name, ",", tt, " },\n", NIL);
+      Printv(variable_tab, tab4, "{ \"", cmodule, "::", iname, "\", MAGIC_CLASS ", set_name, ", MAGIC_CLASS ", get_name, ",", tt, " },\n", NIL);
     }
 
     /* If we're blessed, try to figure out what to do with the variable
@@ -876,8 +882,10 @@ public:
 
     DelWrapper(setf);
     DelWrapper(getf);
+    Delete(getname);
+    Delete(setname);
     Delete(set_name);
-    Delete(val_name);
+    Delete(get_name);
     return SWIG_OK;
   }
 
@@ -970,7 +978,7 @@ public:
     while (p != 0) {
       SwigType *pt = Getattr(p, "type");
       String *pn = Getattr(p, "name");
-      if (!Getattr(p, "ignore")) {
+      if (!checkAttribute(p,"tmap:in:numinputs","0")) {
 	/* If parameter has been named, use that.   Otherwise, just print a type  */
 	if (SwigType_type(pt) != T_VOID) {
 	  if (Len(pn) > 0) {
@@ -982,12 +990,12 @@ public:
 	i++;
 	p = nextSibling(p);
 	if (p)
-	  if (!Getattr(p, "ignore"))
+	  if (!checkAttribute(p,"tmap:in:numinputs","0"))
 	    Putc(',', temp);
       } else {
 	p = nextSibling(p);
 	if (p)
-	  if ((i > 0) && (!Getattr(p, "ignore")))
+	  if ((i > 0) && (!checkAttribute(p,"tmap:in:numinputs","0")))
 	    Putc(',', temp);
       }
     }
@@ -1525,6 +1533,7 @@ public:
 		Printf(pragma_include, "%s", buffer);
 	      }
 	    }
+	    fclose(f);
 	  }
 	} else {
 	  Printf(stderr, "%s : Line %d. Unrecognized pragma.\n", input_file, line_number);
