@@ -8,7 +8,7 @@
  * error messages.
  * ----------------------------------------------------------------------------- */
 
-char cvsroot_error_c[] = "$Header: /cvsroot/swig/SWIG/Source/Swig/error.c,v 1.14 2006/11/01 23:54:53 wsfulton Exp $";
+char cvsroot_error_c[] = "$Id: error.c 9922 2007-08-31 22:20:21Z wsfulton $";
 
 #include "swig.h"
 #include <stdarg.h>
@@ -89,10 +89,14 @@ void Swig_warning(int wnum, const String_or_char *filename, int line, const char
     char *f = Char(filter);
     sprintf(temp, "%d", wnum);
     while (*f != '\0' && (c = strstr(f, temp))) {
-      if (*(c - 1) == '-')
+      if (*(c - 1) == '-') {
 	wrn = 0;		/* Warning disabled */
-      if (*(c - 1) == '+')
+        break;
+      }
+      if (*(c - 1) == '+') {
 	wrn = 1;		/* Warning enabled */
+        break;
+      }
       f += strlen(temp);
     }
   }
@@ -170,7 +174,6 @@ void Swig_warnfilter(const String_or_char *wlist, int add) {
   char *c;
   char *cw;
   String *s;
-
   if (!filter)
     filter = NewStringEmpty();
 
