@@ -10,10 +10,9 @@
  * like typedef, namespaces, etc.
  * ----------------------------------------------------------------------------- */
 
-char cvsroot_typeobj_c[] = "$Header: /cvsroot/swig/SWIG/Source/Swig/typeobj.c,v 1.22 2006/11/01 23:54:54 wsfulton Exp $";
+char cvsroot_typeobj_c[] = "$Id: typeobj.c 9967 2007-10-08 12:02:56Z olly $";
 
 #include "swig.h"
-#include "swigkeys.h"
 #include <ctype.h>
 
 /* -----------------------------------------------------------------------------
@@ -124,7 +123,7 @@ SwigType *NewSwigType(const String_or_char *initial) {
  * static element_size()
  *
  * This utility function finds the size of a single type element in a type string.
- * Type elements are always delimeted by periods, but may be nested with 
+ * Type elements are always delimited by periods, but may be nested with
  * parentheses.  A nested element is always handled as a single item.
  *
  * Returns the integer size of the element (which can be used to extract a 
@@ -557,6 +556,23 @@ int SwigType_isarray(SwigType *t) {
   }
   return 0;
 }
+/*
+ * SwigType_prefix_is_simple_1D_array
+ *
+ * Determine if the type is a 1D array type that is treated as a pointer within SWIG
+ * eg Foo[], Foo[3] return true, but Foo[3][3], Foo*[], Foo*[3], Foo**[] return false
+ */
+int SwigType_prefix_is_simple_1D_array(SwigType *t) {
+  char *c = Char(t);
+
+  if (c && (strncmp(c, "a(", 2) == 0)) {
+    c = strchr(c, '.');
+    c++;
+    return (*c == 0);
+  }
+  return 0;
+}
+
 
 /* Remove all arrays */
 SwigType *SwigType_pop_arrays(SwigType *t) {
@@ -669,7 +685,7 @@ SwigType *SwigType_add_function(SwigType *t, ParmList *parms) {
   for (p = parms; p; p = nextSibling(p)) {
     if (p != parms)
       Putc(',', pstr);
-    Append(pstr, Getattr(p, k_type));
+    Append(pstr, Getattr(p, "type"));
   }
   Insert(t, 0, pstr);
   Delete(pstr);
@@ -764,15 +780,15 @@ SwigType *SwigType_add_template(SwigType *t, ParmList *parms) {
   p = parms;
   for (p = parms; p; p = nextSibling(p)) {
     String *v;
-    if (Getattr(p, k_default))
+    if (Getattr(p, "default"))
       continue;
     if (p != parms)
       Append(t, ",");
-    v = Getattr(p, k_value);
+    v = Getattr(p, "value");
     if (v) {
       Append(t, v);
     } else {
-      Append(t, Getattr(p, k_type));
+      Append(t, Getattr(p, "type"));
     }
   }
   Append(t, ")>");
