@@ -8,7 +8,7 @@
  * deprecated APIs and other features.
  * ----------------------------------------------------------------------------- */
 
-char cvsroot_warn_c[] = "$Header: /cvsroot/swig/SWIG/Source/Swig/warn.c,v 1.4 2006/03/06 22:51:01 wsfulton Exp $";
+char cvsroot_warn_c[] = "$Id: warn.c 9604 2006-12-05 21:57:44Z beazley $";
 
 #include "swig.h"
 
@@ -20,21 +20,15 @@ static Hash *warnings = 0;
  * Issue a warning
  * ----------------------------------------------------------------------------- */
 
-void
-Swig_warn(const char *filename, int line, const char *msg) {
+void Swig_warn(const char *filename, int line, const char *msg) {
   String *key;
   if (!warnings) {
     warnings = NewHash();
   }
-  key = NewStringf("%s:%d", filename,line);
-  if (!Getattr(warnings,key)) {
-    Printf(stderr,"swig-dev warning:%s:%d:%s\n", filename, line, msg);
-    Setattr(warnings,key,key);
+  key = NewStringf("%s:%d", filename, line);
+  if (!Getattr(warnings, key)) {
+    Printf(stderr, "swig-dev warning:%s:%d:%s\n", filename, line, msg);
+    Setattr(warnings, key, key);
   }
   Delete(key);
 }
-
-	
-		
-
-
